@@ -19,12 +19,17 @@
 Docker server module.
 """
 
+import os
 import sys
 import json
 import asyncio
 import logging
 import aiohttp
+import shutil
+import platformdirs
+
 from gns3server.utils import parse_version
+from gns3server.config import Config
 from gns3server.utils.asyncio import locking
 from gns3server.compute.base_manager import BaseManager
 from gns3server.compute.docker.docker_vm import DockerVM
@@ -34,9 +39,9 @@ log = logging.getLogger(__name__)
 
 
 # Be careful to keep it consistent
-DOCKER_MINIMUM_API_VERSION = "1.25"
-DOCKER_MINIMUM_VERSION = "1.13"
-DOCKER_PREFERRED_API_VERSION = "1.30"
+DOCKER_MINIMUM_API_VERSION = "1.40"
+DOCKER_MINIMUM_VERSION = "19.03.8"
+DOCKER_PREFERRED_API_VERSION = "1.44"
 CHUNK_SIZE = 1024 * 8  # 8KB
 
 
@@ -55,27 +60,93 @@ class Docker(BaseManager):
         self._session = None
         self._api_version = DOCKER_MINIMUM_API_VERSION
 
+    @staticmethod
+    async def install_busybox(dst_dir):
+
+        dst_busybox = os.path.join(dst_dir, "bin", "busybox")
+        if os.path.isfile(dst_busybox):
+            return
+        for busybox_exec in ("busybox-static", "busybox.static", "busybox"):
+            busybox_path = shutil.which(busybox_exec)
+            if busybox_path:
+                try:
+                    # check that busybox is statically linked
+                    # (dynamically linked busybox will fail to run in a container)
+                    proc = await asyncio.create_subprocess_exec(
+                        "ldd",
+                        busybox_path,
+                        stdout=asyncio.subprocess.PIPE,
+                        stderr=asyncio.subprocess.DEVNULL
+                    )
+                    stdout, _ = await proc.communicate()
+                    if proc.returncode == 1:
+                        # ldd returns 1 if the file is not a dynamic executable
+                        log.info(f"Installing busybox from '{busybox_path}' to '{dst_busybox}'")
+                        shutil.copy2(busybox_path, dst_busybox, follow_symlinks=True)
+                        return
+                    else:
+                        log.warning(f"Busybox '{busybox_path}' is dynamically linked\n"
+                                    f"{stdout.decode('utf-8', errors='ignore').strip()}")
+                except OSError as e:
+                    raise DockerError(f"Could not install busybox: {e}")
+        raise DockerError("No busybox executable could be found, please install busybox (apt install busybox-static on Debian/Ubuntu) and make sure it is in your PATH")
+
+    @staticmethod
+    def resources_path():
+        """
+        Get the Docker resources storage directory
+        """
+
+        server_config = Config.instance().get_section_config("Server")
+        appname = vendor = "GNS3"
+        resources_path = os.path.expanduser(server_config.get("resources_path", platformdirs.user_data_dir(appname, vendor, roaming=True)))
+        docker_resources_dir = os.path.join(resources_path, "docker")
+        os.makedirs(docker_resources_dir, exist_ok=True)
+        return docker_resources_dir
+
+    async def install_resources(self):
+        """
+        Copy the necessary resources to a writable location and install busybox
+        """
+
+        try:
+            dst_path = self.resources_path()
+            log.info(f"Installing Docker resources in '{dst_path}'")
+            from gns3server.controller import Controller
+            Controller.instance().install_resource_files(dst_path, "compute/docker/resources")
+            await self.install_busybox(dst_path)
+        except OSError as e:
+            raise DockerError(f"Could not install Docker resources to {dst_path}: {e}")
+
     async def _check_connection(self):
 
         if not self._connected:
             try:
                 self._connected = True
-                connector = self.connector()
-                version = await self.query("GET", "version")
+                self._connector = self.connector()
+                docker_info = await self.query("GET", "version")
             except (aiohttp.ClientOSError, FileNotFoundError):
                 self._connected = False
-                raise DockerError("Can't connect to docker daemon")
+                raise DockerError("Can't connect to Docker daemon")
 
-            docker_version = parse_version(version['ApiVersion'])
+            api_version = parse_version(docker_info['ApiVersion'])
+            version = docker_info["Version"]
 
-            if docker_version < parse_version(DOCKER_MINIMUM_API_VERSION):
-                raise DockerError(
-                    "Docker version is {}. GNS3 requires a minimum version of {}".format(
-                        version["Version"], DOCKER_MINIMUM_VERSION))
+            if api_version < parse_version(DOCKER_MINIMUM_API_VERSION):
+                raise DockerError("Docker version is {}. GNS3 requires a minimum version of {}".format(
+                    version,
+                    DOCKER_MINIMUM_VERSION)
+                )
 
             preferred_api_version = parse_version(DOCKER_PREFERRED_API_VERSION)
-            if docker_version >= preferred_api_version:
+            if api_version >= preferred_api_version:
                 self._api_version = DOCKER_PREFERRED_API_VERSION
+            else:
+                # use the Min API version supported by the daemon
+                self._api_version = docker_info['MinAPIVersion']
+                log.warning("Using Docker client with the minimum API version {}".format(self._api_version))
+
+            log.info("Connected to Docker daemon version {} using API version {}".format(version, self._api_version))
 
     def connector(self):
 
@@ -110,11 +181,10 @@ class Docker(BaseManager):
         response = await self.http_query(method, path, data=data, params=params)
         body = await response.read()
         response.close()
-        if body and len(body):
-            if response.headers.get('CONTENT-TYPE') == 'application/json':
-                body = json.loads(body.decode("utf-8"))
-            else:
-                body = body.decode("utf-8")
+        if response.headers.get('CONTENT-TYPE') == 'application/json':
+            body = json.loads(body.decode("utf-8", errors="ignore"))
+        else:
+            body = body.decode("utf-8", errors="ignore")
         log.debug("Query Docker %s %s params=%s data=%s Response: %s", method, path, params, data, body)
         return body
 
@@ -124,7 +194,7 @@ class Docker(BaseManager):
 
         :param method: HTTP method
         :param path: Endpoint in API
-        :param data: Dictionnary with the body. Will be transformed to a JSON
+        :param data: Dictionary with the body. Will be transformed to a JSON
         :param params: Parameters added as a query arg
         :param timeout: Timeout
         :returns: HTTP response
@@ -135,12 +205,11 @@ class Docker(BaseManager):
             timeout = 60 * 60 * 24 * 31  # One month timeout
 
         if path == 'version':
-            url = "http://docker/v1.12/" + path         # API of docker v1.0
+            url = "http://docker/" + path
         else:
-            url = "http://docker/v" + DOCKER_MINIMUM_API_VERSION + "/" + path
+            await self._check_connection()  # version is use by check connection
+            url = "http://docker/v" + self._api_version + "/" + path
         try:
-            if path != "version":  # version is use by check connection
-                await self._check_connection()
             if self._session is None or self._session.closed:
                 connector = self.connector()
                 self._session = aiohttp.ClientSession(connector=connector)
@@ -150,9 +219,9 @@ class Docker(BaseManager):
                                                    data=data,
                                                    headers={"content-type": "application/json", },
                                                    timeout=timeout)
-        except (aiohttp.ClientResponseError, aiohttp.ClientOSError) as e:
+        except aiohttp.ClientError as e:
             raise DockerError("Docker has returned an error: {}".format(str(e)))
-        except (asyncio.TimeoutError):
+        except asyncio.TimeoutError:
             raise DockerError("Docker timeout " + method + " " + path)
         if response.status >= 300:
             body = await response.read()
@@ -198,21 +267,21 @@ class Docker(BaseManager):
             pass
 
         if progress_callback:
-            progress_callback("Pulling '{}' from docker hub".format(image))
+            progress_callback("Pulling '{}' from Docker repository".format(image))
         try:
             response = await self.http_query("POST", "images/create", params={"fromImage": image}, timeout=None)
         except DockerError as e:
-            raise DockerError("Could not pull the '{}' image from Docker Hub, please check your Internet connection (original error: {})".format(image, e))
+            raise DockerError("Could not pull the '{}' image from Docker repository, please check your Internet connection (original error: {})".format(image, e))
         # The pull api will stream status via an HTTP JSON stream
         content = ""
         while True:
             try:
                 chunk = await response.content.read(CHUNK_SIZE)
             except aiohttp.ServerDisconnectedError:
-                log.error("Disconnected from server while pulling Docker image '{}' from docker hub".format(image))
+                log.error("Disconnected from server while pulling Docker image '{}' from Docker repository".format(image))
                 break
             except asyncio.TimeoutError:
-                log.error("Timeout while pulling Docker image '{}' from docker hub".format(image))
+                log.error("Timeout while pulling Docker image '{}' from Docker repository".format(image))
                 break
             if not chunk:
                 break
