@@ -153,6 +153,14 @@ class DockerVM(BaseNode):
     def ethernet_adapters(self):
         return self._ethernet_adapters
 
+    @property
+    def docker_name(self):
+        """
+        Container name in Docker
+        """
+
+        return "GNS3.{}.{}".format(self.name, self._project.id)
+
     @property
     def mac_address(self):
         """
@@ -365,7 +373,7 @@ class DockerVM(BaseNode):
         try:
             image_infos = await self._get_image_information()
         except DockerHttp404Error:
-            log.info("Image '{}' is missing, pulling it from Docker hub...".format(self._image))
+            log.info("Image '{}' is missing, pulling it from Docker repository...".format(self._image))
             await self.pull_image(self._image)
             image_infos = await self._get_image_information()
 
@@ -451,7 +459,8 @@ class DockerVM(BaseNode):
             if extra_hosts:
                 params["Env"].append("GNS3_EXTRA_HOSTS={}".format(extra_hosts))
 
-        result = await self.manager.query("POST", "containers/create", data=params)
+        # Support name in Doker: [a-zA-Z0-9][a-zA-Z0-9_.-]
+        result = await self.manager.query("POST", "containers/create?name={}".format(self.docker_name), data=params)
         self._cid = result['Id']
         log.info("Docker container '{name}' [{id}] created".format(name=self._name, id=self._id))
         return True
@@ -522,6 +531,7 @@ class DockerVM(BaseNode):
             await self._clean_servers()
 
             await self.manager.query("POST", "containers/{}/start".format(self._cid))
+            await asyncio.sleep(0.5)  # give the Docker container some time to start
             self._namespace = await self._get_namespace()
 
             await self._start_ubridge(require_privileged_access=True)
