@@ -25,7 +25,10 @@ PATH=/gns3/bin:/tmp/gns3/bin:/sbin:$PATH
 # bootstrap busybox commands
 if [ ! -d /tmp/gns3/bin ]; then
 	busybox mkdir -p /tmp/gns3/bin
-	/gns3/bin/busybox --install -s /tmp/gns3/bin
+	for applet in `busybox --list`
+	do
+	  ln -s /gns3/bin/busybox "/tmp/gns3/bin/$applet"
+	done
 fi
 
 #  Restore file permission and mount volumes
@@ -75,7 +78,7 @@ ip link set dev lo up
 while true 
 do
     grep $GNS3_MAX_ETHERNET /proc/net/dev > /dev/null && break
-    sleep 0.5
+    usleep 500000  # wait 0.5 seconds
 done  
 
 # activate eth interfaces
@@ -87,5 +90,13 @@ done
 ifup -a -f
 
 # continue normal docker startup
-eval HOME=$(echo ~${GNS3_USER-root})
+case "$GNS3_USER" in
+  [1-9][0-9]*)
+    # for when the user field defined in the Docker container is an ID
+    export GNS3_USER=$(cat /etc/passwd | grep ${GNS3_USER-root} | awk -F: '{print $1}')
+    ;;
+  *)
+    ;;
+esac
+eval HOME="$(echo ~${GNS3_USER-root})"
 exec su ${GNS3_USER-root} -p -- /gns3/run-cmd.sh "$OLD_PATH" "$@"
