@@ -29,7 +29,8 @@ except ImportError:
     from importlib import resources as importlib_resources
 
 from ..config import Config
-from ..utils import parse_version
+from ..utils import parse_version, md5sum
+from ..utils.images import default_images_directory
 
 from .project import Project
 from .template import Template
@@ -72,6 +73,7 @@ class Controller:
 
         log.info("Controller is starting")
         self._install_base_configs()
+        self._install_builtin_disks()
         server_config = Config.instance().get_section_config("Server")
         Config.instance().listen_for_config_changes(self._update_config)
         host = server_config.get("host", "localhost")
@@ -189,29 +191,28 @@ class Controller:
         Save the controller configuration on disk
         """
 
-        if self._config_loaded is False:
-            return
+        controller_settings = dict()
+        if self._config_loaded:
+            controller_settings = {"computes": [],
+                                   "templates": [],
+                                   "gns3vm": self.gns3vm.__json__(),
+                                   "iou_license": self._iou_license_settings,
+                                   "appliances_etag": self._appliance_manager.appliances_etag,
+                                   "version": __version__}
 
-        controller_settings = {"computes": [],
-                               "templates": [],
-                               "gns3vm": self.gns3vm.__json__(),
-                               "iou_license": self._iou_license_settings,
-                               "appliances_etag": self._appliance_manager.appliances_etag,
-                               "version": __version__}
+            for template in self._template_manager.templates.values():
+                if not template.builtin:
+                    controller_settings["templates"].append(template.__json__())
 
-        for template in self._template_manager.templates.values():
-            if not template.builtin:
-                controller_settings["templates"].append(template.__json__())
-
-        for compute in self._computes.values():
-            if compute.id != "local" and compute.id != "vm":
-                controller_settings["computes"].append({"host": compute.host,
-                                                        "name": compute.name,
-                                                        "port": compute.port,
-                                                        "protocol": compute.protocol,
-                                                        "user": compute.user,
-                                                        "password": compute.password,
-                                                        "compute_id": compute.id})
+            for compute in self._computes.values():
+                if compute.id != "local" and compute.id != "vm":
+                    controller_settings["computes"].append({"host": compute.host,
+                                                            "name": compute.name,
+                                                            "port": compute.port,
+                                                            "protocol": compute.protocol,
+                                                            "user": compute.user,
+                                                            "password": compute.password,
+                                                            "compute_id": compute.id})
 
         try:
             os.makedirs(os.path.dirname(self._config_file), exist_ok=True)
@@ -227,8 +228,7 @@ class Controller:
 
         try:
             if not os.path.exists(self._config_file):
-                self._config_loaded = True
-                self.save()
+                self.save()  # this will create the config file
             with open(self._config_file) as f:
                 controller_settings = json.load(f)
         except (OSError, ValueError) as e:
@@ -248,9 +248,19 @@ class Controller:
         if "iou_license" in controller_settings:
             self._iou_license_settings = controller_settings["iou_license"]
 
-        previous_version = controller_settings.get("version")
-        if not previous_version or parse_version(__version__) > parse_version(previous_version):
-            self._appliance_manager.install_builtin_appliances()
+        # install the built-in appliances if needed
+        server_config = Config.instance().get_section_config("Server")
+        if server_config.getboolean("install_builtin_appliances", True):
+            previous_version = controller_settings.get("version")
+            log.info("Comparing controller version {} with config version {}".format(__version__, previous_version))
+            builtin_appliances_path = self._appliance_manager.builtin_appliances_path()
+            if not previous_version or \
+                    parse_version(__version__.split("+")[0]) > parse_version(previous_version.split("+")[0]):
+                self._appliance_manager.install_builtin_appliances()
+            elif not os.listdir(builtin_appliances_path):
+                self._appliance_manager.install_builtin_appliances()
+            else:
+                log.info("Built-in appliances are installed in '{}'".format(builtin_appliances_path))
 
         self._appliance_manager.appliances_etag = controller_settings.get("appliances_etag")
         self._appliance_manager.load_appliances()
@@ -279,29 +289,62 @@ class Controller:
         except OSError as e:
             log.error(str(e))
 
+
+    @staticmethod
+    def install_resource_files(dst_path, resource_name, upgrade_resources=True):
+        """
+        Install files from resources to user's file system
+        """
+
+        def should_copy(src, dst, upgrade_resources):
+            if not os.path.exists(dst):
+                return True
+            if upgrade_resources is False:
+                return False
+            # copy the resource if it is different
+            return md5sum(src) != md5sum(dst)
+
+        if hasattr(sys, "frozen") and sys.platform.startswith("win"):
+            resource_path = os.path.normpath(os.path.join(os.path.dirname(sys.executable), resource_name))
+            for filename in os.listdir(resource_path):
+                if not os.path.exists(os.path.join(dst_path, filename)):
+                    shutil.copy(os.path.join(resource_path, filename), os.path.join(dst_path, filename))
+        else:
+            for entry in importlib_resources.files('gns3server').joinpath(resource_name).iterdir():
+                full_path = os.path.join(dst_path, entry.name)
+                if entry.is_file() and should_copy(str(entry), full_path, upgrade_resources):
+                    log.debug(f'Installing {resource_name} resource file "{entry.name}" to "{full_path}"')
+                    shutil.copy(str(entry), os.path.join(dst_path, entry.name))
+                elif entry.is_dir():
+                    os.makedirs(full_path, exist_ok=True)
+                    Controller.install_resource_files(full_path, os.path.join(resource_name, entry.name))
+
     def _install_base_configs(self):
         """
-        At startup we copy base file to the user location to allow
+        At startup we copy base configs to the user location to allow
         them to customize it
         """
 
         dst_path = self.configs_path()
         log.info(f"Installing base configs in '{dst_path}'")
         try:
-            if hasattr(sys, "frozen") and sys.platform.startswith("win"):
-                resource_path = os.path.normpath(os.path.join(os.path.dirname(sys.executable), "configs"))
-                for filename in os.listdir(resource_path):
-                    if not os.path.exists(os.path.join(dst_path, filename)):
-                        shutil.copy(os.path.join(resource_path, filename), os.path.join(dst_path, filename))
-            else:
-                for entry in importlib_resources.files('gns3server.configs').iterdir():
-                    full_path = os.path.join(dst_path, entry.name)
-                    if entry.is_file() and not os.path.exists(full_path):
-                        log.debug(f"Installing base config file {entry.name} to {full_path}")
-                        shutil.copy(str(entry), os.path.join(dst_path, entry.name))
+            Controller.install_resource_files(dst_path, "configs", upgrade_resources=False)
         except OSError as e:
             log.error(f"Could not install base config files to {dst_path}: {e}")
 
+    def _install_builtin_disks(self):
+        """
+        At startup we copy built-in Qemu disks to the user location to allow
+        them to use with appliances
+        """
+
+        dst_path = self.disks_path()
+        log.info(f"Installing built-in disks in '{dst_path}'")
+        try:
+            Controller.install_resource_files(dst_path, "disks", upgrade_resources=False)
+        except OSError as e:
+            log.error(f"Could not install disk files to {dst_path}: {e}")
+
     def images_path(self):
         """
         Get the image storage directory
@@ -322,6 +365,15 @@ class Controller:
         os.makedirs(configs_path, exist_ok=True)
         return configs_path
 
+    def disks_path(self, emulator_type="qemu"):
+        """
+        Get the disks storage directory
+        """
+
+        disks_path = default_images_directory(emulator_type)
+        os.makedirs(disks_path, exist_ok=True)
+        return disks_path
+
     async def add_compute(self, compute_id=None, name=None, force=False, connect=True, **kwargs):
         """
         Add a server to the dictionary of computes controlled by this controller
