@@ -18,14 +18,19 @@
 import ipaddress
 import aiohttp
 import asyncio
-import async_timeout
 import socket
 import json
 import uuid
 import sys
 import io
+
 from operator import itemgetter
 
+if sys.version_info >= (3, 11):
+    from asyncio import timeout as asynctimeout
+else:
+    from async_timeout import timeout as asynctimeout
+
 from ..utils import parse_version
 from ..utils.asyncio import locking
 from ..controller.controller_error import ControllerError
@@ -450,7 +455,7 @@ class Compute:
                         elif response.type == aiohttp.WSMsgType.CLOSED:
                             pass
                         break
-        except aiohttp.client_exceptions.ClientResponseError as e:
+        except aiohttp.ClientError as e:
             log.error("Client response error received on compute '{}' WebSocket '{}': {}".format(self._id, ws_url,e))
         finally:
             self._connected = False
@@ -483,8 +488,8 @@ class Compute:
         """ Returns URL for specific path at Compute"""
         return self._getUrl(path)
 
-    async def _run_http_query(self, method, path, data=None, timeout=20, raw=False):
-        with async_timeout.timeout(timeout):
+    async def _run_http_query(self, method, path, data=None, timeout=120, raw=False):
+        async with asynctimeout(delay=timeout):
             url = self._getUrl(path)
             headers = {}
             headers['content-type'] = 'application/json'
