@@ -17,6 +17,7 @@
 
 import aiohttp
 import asyncio
+import ipaddress
 
 from gns3server.web.route import Route
 from gns3server.controller import Controller
@@ -477,11 +478,27 @@ class NodeHandler:
         await ws.prepare(request)
         request.app['websockets'].add(ws)
 
-        ws_console_compute_url = "ws://{compute_host}:{compute_port}/v2/compute/projects/{project_id}/{node_type}/nodes/{node_id}/console/ws".format(compute_host=compute.host,
-                                                                                                                                                     compute_port=compute.port,
-                                                                                                                                                     project_id=project.id,
-                                                                                                                                                     node_type=node.node_type,
-                                                                                                                                                     node_id=node.id)
+        compute_host = compute.host
+        try:
+            # handle IPv6 address
+            ip = ipaddress.ip_address(compute_host)
+            if isinstance(ip, ipaddress.IPv6Address):
+                compute_host = '[' + compute_host + ']'
+        except ValueError:
+            pass
+
+        ws_protocol = "ws"
+        if request.scheme == "https":
+            ws_protocol = "wss"
+
+        ws_console_compute_url = "{protocol}://{compute_host}:{compute_port}/v2/compute/projects/{project_id}/{node_type}/nodes/{node_id}/console/ws".format(
+            protocol=ws_protocol,
+            compute_host=compute_host,
+            compute_port=compute.port,
+            project_id=project.id,
+            node_type=node.node_type,
+            node_id=node.id
+        )
 
         async def ws_forward(ws_client):
             async for msg in ws:
@@ -494,7 +511,7 @@ class NodeHandler:
 
         try:
             async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(limit=None, force_close=True)) as session:
-                async with session.ws_connect(ws_console_compute_url) as ws_client:
+                async with session.ws_connect(ws_console_compute_url, ssl=False) as ws_client:
                     asyncio.ensure_future(ws_forward(ws_client))
                     async for msg in ws_client:
                         if msg.type == aiohttp.WSMsgType.TEXT:
@@ -505,6 +522,8 @@ class NodeHandler:
                             break
         except ConnectionResetError:
             log.info("Websocket console connection with compute disconnected")
+        except aiohttp.ClientError as e:
+            log.error("Websocket console connection with compute failed: {}".format(e))
         finally:
             if not ws.closed:
                 await ws.close()
