@@ -232,8 +232,7 @@ class Route(object):
                     response.set_status(408)
                     response.json({"message": "Request canceled", "status": 408})
                     raise  # must raise to let aiohttp know the connection has been closed
-                except aiohttp.ClientError:
-                    log.warning("Client error")
+                except (ConnectionResetError, aiohttp.ClientError):
                     response = Response(request=request, route=route)
                     response.set_status(408)
                     response.json({"message": "Client error", "status": 408})
